@@ -17,7 +17,7 @@
 
 #include "k3b_export.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace K3b {
     class Job;
