@@ -13,8 +13,8 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#ifndef K3BMP3MODULE_H
-#define K3BMP3MODULE_H
+#ifndef _K3B_MAD_DECODER_H_
+#define _K3B_MAD_DECODER_H_
 
 
 #include "k3baudiodecoder.h"
@@ -29,7 +29,7 @@ class K3bMadDecoderFactory : public K3b::AudioDecoderFactory
     Q_OBJECT
 
 public:
-    K3bMadDecoderFactory( QObject* parent = 0, const QVariantList& args = QVariantList() );
+    explicit K3bMadDecoderFactory( QObject* parent = 0, const QVariantList& args = QVariantList() );
     ~K3bMadDecoderFactory();
 
     bool canDecode( const QUrl& filename );
@@ -45,7 +45,7 @@ class K3bMadDecoder : public K3b::AudioDecoder
     Q_OBJECT
 
 public:
-    K3bMadDecoder( QObject* parent = 0 );
+    explicit K3bMadDecoder( QObject* parent = 0 );
     ~K3bMadDecoder();
 
     QString metaInfo( MetaDataField );
