@@ -16,14 +16,14 @@
 #ifndef _K3B_LAME_MANUAL_SETTINGS_DIALOG_H_
 #define _K3B_LAME_MANUAL_SETTINGS_DIALOG_H_
 
-#include <QtWidgets/QDialog>
+#include <QDialog>
 
 #include "ui_base_k3bmanualbitratesettingsdialog.h"
 
 class K3bLameManualSettingsDialog : public QDialog, public Ui::K3bManualBitrateSettingsDialog
 {
 public:
-    K3bLameManualSettingsDialog( QWidget* parent = 0 );
+    explicit K3bLameManualSettingsDialog( QWidget* parent = 0 );
     ~K3bLameManualSettingsDialog();
 };
 
