@@ -21,8 +21,8 @@
 #include "k3bdebuggingoutputcache.h"
 #include "k3bjobhandler.h"
 
-#include <QtCore/QElapsedTimer>
-#include <QtWidgets/QDialog>
+#include <QElapsedTimer>
+#include <QDialog>
 
 class KSqueezedTextLabel;
 class QCloseEvent;
@@ -43,7 +43,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        JobProgressDialog( QWidget* parent = 0,
+        explicit JobProgressDialog( QWidget* parent = 0,
                            bool showSubProgress = true );
         ~JobProgressDialog();
 
