@@ -18,8 +18,8 @@
 
 #include <KConfigCore/KConfigGroup>
 #include <KIOCore/KIO/Global>
-#include <QtWidgets/QGroupBox>
-#include <QtWidgets/QLabel>
+#include <QGroupBox>
+#include <QLabel>
 
 class QLabel;
 class KUrlRequester;
@@ -34,7 +34,7 @@ class TempDirSelectionWidget : public QGroupBox
     Q_OBJECT
 
 public: 
-    TempDirSelectionWidget( QWidget *parent = 0 );
+    explicit TempDirSelectionWidget( QWidget *parent = 0 );
     ~TempDirSelectionWidget();
 
     /** determines if the selection dialog should ask for a dir or a file */
