@@ -24,23 +24,23 @@
 #include <KConfigCore/KConfigGroup>
 #include <KCoreAddons/KAboutData>
 #include <KIconThemes/KIconLoader>
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 #include <KXmlGui/KActionCollection>
 
-#include <QtCore/QMimeData>
-#include <QtCore/QUrl>
-#include <QtGui/QIcon>
-#include <QtGui/QCursor>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QPaintEvent>
-#include <QtGui/QResizeEvent>
-#include <QtGui/QShowEvent>
-#include <QtGui/QTextDocument>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QStyle>
+#include <QMimeData>
+#include <QUrl>
+#include <QIcon>
+#include <QCursor>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QPaintEvent>
+#include <QResizeEvent>
+#include <QShowEvent>
+#include <QTextDocument>
+#include <QMenu>
+#include <QStyle>
 
 namespace {
 
@@ -269,7 +269,7 @@ void K3b::WelcomeWidget::slotThemeChanged()
 
     m_header->setHtml( "<html><body align=\"center\">" + i18n("Welcome to K3b &ndash; The CD, DVD, and Blu-ray Kreator") + "</body></html>" );
     m_infoText->setHtml( "<html><body align=\"center\">" 
-                         + i18n("K3b %1 Copyright &copy; 1998&ndash;2017 K3b authors",
+                         + i18n("K3b %1 Copyright &copy; 1998&ndash;2018 K3b authors",
                                 KAboutData::applicationData().version())
                          + "</body></html>" );
     setMinimumWidth( 2*MARGIN + qMax(( int )m_header->idealWidth(), m_buttonSize.width()) );
