@@ -18,7 +18,7 @@
 #include "ui_base_k3baudiorippingoptionwidget.h"
 
 #include <KIOCore/KIO/Global>
-#include <QtWidgets/QCheckBox>
+#include <QCheckBox>
 
 class KConfigGroup;
 
@@ -34,7 +34,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        AudioConvertingOptionWidget( QWidget* parent );
+        explicit AudioConvertingOptionWidget( QWidget* parent );
         ~AudioConvertingOptionWidget();
 
         void setBaseDir( const QString& path );
