@@ -19,7 +19,7 @@
 #include "k3bvideodvd.h"
 #include "k3bvideodvdtitletranscodingjob.h"
 
-#include <QtCore/QVector>
+#include <QVector>
 
 
 namespace K3b {
@@ -39,7 +39,7 @@ namespace K3b {
         class TitleRipInfo {
         public:
             TitleRipInfo();
-            TitleRipInfo( int title,
+            explicit TitleRipInfo( int title,
                           int audioStream = 0,
                           const QString& fn = QString(),
                           int width = 0,  // 0 -> no resize
